==> listvennica-0.0.11-sources.jar: listvennica/ListvennicaClient.java <==

package listvennica;

import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.blockrenderlayer.v1.BlockRenderLayerMap;
import net.minecraft.class_1921;

public class ListvennicaClient implements ClientModInitializer {
	@Override
	public void onInitializeClient () {
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.TEST_BLOCK, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_ACACIA_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_BIRCH_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_BLOCK_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_BAMBOO_BLOCK_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_CHERRY_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_STEM_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_CRIMSON_STEM_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_DARK_OAK_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_JUNGLE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_MANGROVE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_OAK_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_SPRUCE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_STEM_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_WARPED_STEM_SLAB, class_1921.method_23581 ());
	}
}

==> listvennica-0.0.13-sources.jar: listvennica/ListvennicaClient.java <==

package listvennica;

import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.blockrenderlayer.v1.BlockRenderLayerMap;
import net.minecraft.class_1921;

public class ListvennicaClient implements ClientModInitializer {
	@Override
	public void onInitializeClient () {
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.TEST_BLOCK, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.ACACIA_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_ACACIA_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BIRCH_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_BIRCH_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.BAMBOO_BLOCK_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_BAMBOO_BLOCK_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CHERRY_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_CHERRY_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.CRIMSON_STEM_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_CRIMSON_STEM_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.DARK_OAK_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_DARK_OAK_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.JUNGLE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_JUNGLE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.MANGROVE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_MANGROVE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.OAK_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_OAK_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.SPRUCE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_SPRUCE_LOG_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_PLANK_WINDOW, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_SIBSTYLE_WINDOW_SHUTTER, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_WOODEN_MOTIF_ICICLES, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_WOODEN_MOTIF_SNAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_WOODEN_MOTIF_SNOWFLAKE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_WOODEN_MOTIF_SPRUCE_CONE, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.WARPED_STEM_SLAB, class_1921.method_23581 ());
		BlockRenderLayerMap.INSTANCE.putBlock (ModBlocks.STRIPPED_WARPED_STEM_SLAB, class_1921.method_23581 ());
	}
}
